@@ -11,7 +11,7 @@ use Data::Printer;
 use Encode;
 my $APIKEY = $ENV{MYPEOPLE_APIKEY}; 
 
-my $bot = Net::MyPeople::Bot->new({apikey=>$APIKEY});
+my $bot = Net::MyPeople::Bot->new(apikey=>$APIKEY, web_proxy_base=>'http://localhost:8080/proxy/');
 my $from = 0;
 my $to = 5000;
 
@@ -24,7 +24,6 @@ while($to != $from ){
 	my $msg = '한' x $half;
 	$res = $bot->send('BU_wqPHjxmJKIxKcIrAQu-JiA00', $msg, undef, 1 );
 	#$res = $bot->groupSend('GID_WZrl1', 'X' x $half );
-	p $res;
 	if( $res->{code} eq '200' ){
 		$from = $half;
 	}
